@@ -39,24 +39,22 @@ an easier, more friendly interface to this information.
 
 =cut
 
-# Load Overhead: 236k
-
 use 5.005;
 # We don't want to use strict refs, since we do a lot of things in here
 # that arn't strict refs friendly.
-use strict     qw{vars subs};
+use strict qw{vars subs};
 use File::Spec ();
 
 # Globals
 use vars qw{$VERSION $RE_IDENT $RE_CLASS $UNIX};
 BEGIN {
-	$VERSION = '1.15';
+	$VERSION = '1.17';
 
 	# Predefine some regexs
 	$RE_IDENT = qr/\A[^\W\d]\w*\z/s;
-	$RE_CLASS = qr/\A[^\W\d]\w*(?:(?:'|::)[^\W\d]\w*)*\z/s;
+	$RE_CLASS = qr/\A[^\W\d]\w*(?:(?:'|::)\w+)*\z/s;
 
-	# Are we on Unix?
+	# Are we on something Unix-like?
 	$UNIX = !! ( $File::Spec::ISA[0] eq 'File::Spec::Unix' );
 }
 
@@ -612,7 +610,7 @@ For other issues, or commercial enhancement or support, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
@@ -620,7 +618,7 @@ L<http://ali.as/>, L<Class::Handle>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 - 2006 Adam Kennedy. All rights reserved.
+Copyright (c) 2002 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
